### Name: vuong
### Title: Vuong's test for non-nested model comparison
### Aliases: vuong
### Keywords: models

### ** Examples

data(Seatbelts)
DriversKilled <- as.vector(Seatbelts[,1])           # will be response
kms <- as.vector(Seatbelts[,5]/mean(Seatbelts[,5])) # will be exposure
PetrolPrice <- as.vector(Seatbelts[,6])             # will be covariate 1
law <- as.vector(Seatbelts[,8])                     # will be covariate 2

fm.X.poi <- ~ PetrolPrice + law

fm.X.gp <- ~ PetrolPrice + law
fm.W.gp <- ~ 1

fm.X.zigp <- ~ PetrolPrice + law
fm.W.zigp <- ~ 1
fm.Z.zigp <- ~ 1

poi  <- mle.zigp(Yin=DriversKilled, fm.X=fm.X.poi,  fm.W=NULL,
                 fm.Z=NULL,  Offset = kms, init = FALSE)
gp   <- mle.zigp(Yin=DriversKilled, fm.X=fm.X.gp,   fm.W=fm.W.gp,
                 fm.Z=NULL,  Offset = kms, init = FALSE)
zigp <- mle.zigp(Yin=DriversKilled, fm.X=fm.X.zigp, fm.W=fm.W.zigp,
                 fm.Z=fm.Z.zigp, Offset = kms, init = FALSE)
# it is possible to compare to a Negative Binomial fit:
library(MASS)
nb   <- glm.nb(DriversKilled ~ offset(log(kms)) + PetrolPrice + law)

vuong(poi,gp)
vuong(gp,zigp)
vuong(poi,zigp)
vuong(gp,nb)

# compare: since gp and zigp are almost identical for this data (zero-
# inflation is estimated to be zero), the Schwarz correction for the
# (unnecessary) additional parameter has a great impact:

# GP with constant overdispersion
fm.X <- ~ PetrolPrice + law
fm.W <- ~ 1
est.zigp(DriversKilled, fm.X, fm.W, NULL, Offset = kms)

# ZIGP with constant overdispersion and constant zero-inflation
fm.X <- ~ PetrolPrice + law
fm.W <- ~ 1
fm.Z <- ~ 1
est.zigp(DriversKilled, fm.X, fm.W, fm.Z, Offset = kms)

vuong(gp,zigp, correction=FALSE)
vuong(gp,zigp)



